---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!--
  Sentry/Codecov employees and contractors can delete or ignore the following.
-->

# 📣 Feedback / 🐛 Bugs

Do you want to file a bug report and/or feature request for Codecov? [Please use our feedback repo instead](https://github.com/codecov/feedback/issues).
